/*
 * Copyright (c) 2010 LAAS/CNRS
 * Arnaud Degroote - Wed Aug 11 2010
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#ifndef _BUF_H_
#define _BUF_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <stddef.h>

struct buf
{
	char* data;
	size_t len;
	size_t allocated;
};

typedef struct buf* buf_t;

buf_t buf_init();
void buf_destroy(buf_t*);
int buf_reserve(buf_t, size_t);

void buf_cat(buf_t, const char* format, ...);
void buf_add_char(buf_t, char*, int nDim, int *dims);
void buf_add_addr(buf_t, void**, int nDim, int *dims);
void buf_add_double(buf_t, double*, int nDim, int *dims);
void buf_add_float(buf_t, float*, int nDim, int *dims);
void buf_add_int(buf_t, int*, int nDim, int *dims);
void buf_add_long_int(buf_t, long int*, int nDim, int *dims);
void buf_add_long_long_int(buf_t, long long int*, int nDim, int *dims);
void buf_add_short_int(buf_t, short int*, int nDim, int *dims);
void buf_add_string(buf_t, char *x, int nDim, int *dims);
void buf_add_unsigned_char(buf_t, unsigned char *x, int nDim, int *dims);
void buf_add_unsigned_int(buf_t, unsigned int *x, int nDim, int *dims);
void buf_add_unsigned_long_int(buf_t, unsigned long *x, int nDim, int *dims);
void buf_add_unsigned_long_long_int(buf_t, unsigned long long *x, int nDim, int *dims);
void buf_add_unsigned_short_int(buf_t, unsigned short *x, int nDim, int *dims);

#ifdef __cplusplus
}
#endif

#endif /* */
